package com.vcarecity.publish.elastic.service.impl;

import com.vcarecity.publish.elastic.service.ElasticIndexService;
import lombok.extern.slf4j.Slf4j;
import org.elasticsearch.action.admin.indices.delete.DeleteIndexRequest;
import org.elasticsearch.client.RequestOptions;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.client.indices.CreateIndexRequest;
import org.elasticsearch.client.indices.CreateIndexResponse;
import org.elasticsearch.client.indices.GetIndexRequest;
import org.elasticsearch.common.xcontent.XContentType;
import org.springframework.stereotype.Service;

import java.io.IOException;
import java.util.List;

/**
 * @author kerryzhang on 2019/12/17
 */

@Slf4j
@Service
public class ElasticIndexServiceImpl implements ElasticIndexService {

    private final RestHighLevelClient restHighLevelClient;

    public ElasticIndexServiceImpl(RestHighLevelClient restHighLevelClient) {
        this.restHighLevelClient = restHighLevelClient;
    }

    @Override
    public boolean indexExist(String index) throws IOException {
        GetIndexRequest request = new GetIndexRequest(index);
        return restHighLevelClient.indices().exists(request, RequestOptions.DEFAULT);
    }

    @Override
    public boolean createIndex(String index) throws IOException {

        CreateIndexRequest request = new CreateIndexRequest(index);

        // mapping
        //language=JSON
        String mapping = "{\n" +
                "  \"properties\": {\n" +
                "    \"agencyName\": {\n" +
                "      \"type\": \"text\",\n" +
                "      \"analyzer\": \"ik_max_word\",\n" +
                "      \"search_analyzer\": \"ik_smart\"\n" +
                "    },\n" +
                "    \"agencyDetail\": {\n" +
                "      \"type\": \"text\",\n" +
                "      \"analyzer\": \"ik_max_word\",\n" +
                "      \"search_analyzer\": \"ik_smart\"\n" +
                "    },\n" +
                "    \"nameOfBuilding\": {\n" +
                "      \"type\": \"text\",\n" +
                "      \"analyzer\": \"ik_max_word\",\n" +
                "      \"search_analyzer\": \"ik_smart\"\n" +
                "    }\n" +
                "  " +
                "}\n" +
                "}";

        request.mapping(mapping, XContentType.JSON);

        CreateIndexResponse createIndexResponse = restHighLevelClient.indices().create(request, RequestOptions.DEFAULT);

        return createIndexResponse.isAcknowledged();

    }

    @Override
    public void deleteIndex(String... indices) throws IOException {
        logger.warn("delete elastic index = {}", indices);
        DeleteIndexRequest request = new DeleteIndexRequest(indices);
        restHighLevelClient.indices().delete(request, RequestOptions.DEFAULT);
    }

    @Override
    public List<String> indices() {
        return null;
    }


}
